<!DOCTYPE html>
{% load static %}
<html>
<head>
    <title>django-yarnpkg demo</title>
    <script type="text/javascript" src='{% static 'jquery/dist/jquery.js' %}'></script>
    <script type="text/javascript" src='{% static 'underscore/underscore.js' %}'></script>
    <script type="text/javascript">
        $(function(){
            $('body').append('<p>jquery work</p>');

            if (_) {
                $('body').append('<p>underscore work</p>');
            }
        });
    </script>
</head>
<body>
</body>
</html>
